@@ -15,10 +15,19 @@
 
 import abc
 import collections
+
+# (rpittau) this allows usage of collection ABC abstract classes in both
+# Python 2.7 and Python 3.8+
+try:
+    collectionsAbc = collections.abc
+except AttributeError:
+    collectionsAbc = collections
+
 import copy
 import io
 import json
 import logging
+import pkg_resources
 import zipfile
 
 import six
@@ -111,7 +120,7 @@ def _collect_fields(resource):
 
 
 @six.add_metaclass(abc.ABCMeta)
-class CompositeField(collections.Mapping, Field):
+class CompositeField(collectionsAbc.Mapping, Field):
     """Base class for fields consisting of several sub-fields."""
 
     def __init__(self, *args, **kwargs):
@@ -143,6 +152,7 @@ class CompositeField(collections.Mapping, Field):
 
     # Satisfy the mapping interface, see
     # https://docs.python.org/2/library/collections.html#collections.Mapping.
+    # https://docs.python.org/3/library/collections.abc.html#collections.abc.Mapping
 
     def __getitem__(self, key):
         if key in self._subfields:
@@ -240,7 +250,7 @@ class MappedField(Field):
             Only has effect when the field is not required. This value is not
             matched against the mapping.
         """
-        if not isinstance(mapping, collections.Mapping):
+        if not isinstance(mapping, collectionsAbc.Mapping):
             raise TypeError("The mapping argument must be a mapping")
 
         super(MappedField, self).__init__(
@@ -273,6 +283,14 @@ class JsonDataReader(AbstractJsonReader):
         return self._conn.get(path=self._path).json()
 
 
+class JsonPublicFileReader(AbstractJsonReader):
+    """Loads the data from the Internet"""
+
+    def get_json(self):
+        """Get JSON file from full URI"""
+        return self._conn.get(self._path).json()
+
+
 class JsonArchiveReader(AbstractJsonReader):
     """Gets the data from JSON file in archive"""
 
@@ -300,6 +318,24 @@ class JsonArchiveReader(AbstractJsonReader):
                       {'type': data.headers['content-type']})
 
 
+class JsonPackagedFileReader(AbstractJsonReader):
+    """Gets the data from packaged file given by path"""
+
+    def __init__(self, resource_package_name):
+        """Initializes the reader
+
+        :param resource_package: Python package/module name
+        """
+        self._resource_package_name = resource_package_name
+
+    def get_json(self):
+        """Gets JSON file from packaged file denoted by path"""
+
+        with pkg_resources.resource_stream(self._resource_package_name,
+                                           self._path) as resource:
+            return json.loads(resource.read().decode(encoding='utf-8'))
+
+
 @six.add_metaclass(abc.ABCMeta)
 class ResourceBase(object):
 
@@ -313,7 +349,7 @@ class ResourceBase(object):
                  connector,
                  path='',
                  redfish_version=None,
-                 reader=JsonDataReader()):
+                 reader=None):
         """A class representing the base of any Redfish resource
 
         Invokes the ``refresh()`` method of resource for the first
@@ -322,8 +358,7 @@ class ResourceBase(object):
         :param path: sub-URI path to the resource.
         :param redfish_version: The version of Redfish. Used to construct
             the object according to schema of the given version.
-        :param reader: Reader to use to fetch JSON data. Defaults to
-            JsonDataReader
+        :param reader: Reader to use to fetch JSON data.
         """
         self._conn = connector
         self._path = path
@@ -334,6 +369,8 @@ class ResourceBase(object):
         # attribute values are fetched.
         self._is_stale = True
 
+        if reader is None:
+            reader = JsonDataReader()
         reader.set_connection(connector, path)
         self._reader = reader
 
