@@ -19,6 +19,7 @@ from sushy import exceptions
 from sushy.resources import base
 from sushy.resources import common
 from sushy.resources import settings
+from sushy import utils
 
 LOG = logging.getLogger(__name__)
 
@@ -30,6 +31,17 @@ class ActionsField(base.CompositeField):
 
 class Bios(base.ResourceBase):
 
+    def __init__(self, connector, path, registries, *args, **kwargs):
+        super(Bios, self).__init__(connector, path, *args, **kwargs)
+        self._registries = registries
+        """A class representing a Bios
+
+        :param connector: A Connector instance
+        :param path: Sub-URI path to the Bios resource
+        :param registries: Dict of message registries to be used when
+            parsing messages of attribute update status
+        """
+
     identity = base.Field('Id', required=True)
     """The Bios resource identity string"""
 
@@ -56,24 +68,30 @@ class Bios(base.ResourceBase):
 
     _actions = ActionsField('Actions')
 
-    _pending_settings_resource = None
+    _apply_time_settings = settings.SettingsApplyTimeField()
+
+    @property
+    @utils.cache_it
+    def _pending_settings_resource(self):
+        """Pending BIOS settings resource"""
+        return Bios(
+            self._conn, self._settings.resource_uri,
+            registries=None,
+            redfish_version=self.redfish_version)
 
     @property
     def pending_attributes(self):
         """Pending BIOS attributes
 
-        BIOS attributes that have been comitted to the system,
+        BIOS attributes that have been committed to the system,
         but for them to take effect system restart is necessary
         """
-
-        if not self._pending_settings_resource:
-            self._pending_settings_resource = Bios(
-                self._conn,
-                self._settings.resource_uri,
-                redfish_version=self.redfish_version)
-        self._pending_settings_resource.refresh(force=False)
         return self._pending_settings_resource.attributes
 
+    @property
+    def apply_time_settings(self):
+        return self._pending_settings_resource._apply_time_settings
+
     def set_attribute(self, key, value):
         """Update an attribute
 
@@ -97,8 +115,8 @@ class Bios(base.ResourceBase):
         """
         self._settings.commit(self._conn,
                               {'Attributes': value})
-        if self._pending_settings_resource:
-            self._pending_settings_resource.invalidate()
+        utils.cache_clear(self, force_refresh=False,
+                          only_these=['_pending_settings_resource'])
 
     def _get_reset_bios_action_element(self):
         actions = self._actions
@@ -148,12 +166,11 @@ class Bios(base.ResourceBase):
                                           'PasswordName': password_name})
         LOG.info('BIOS password %s is being changed', self.identity)
 
-    def _do_refresh(self, force=False):
-        """Do custom resource specific refresh activities
+    @property
+    def update_status(self):
+        """Status of the last attribute update
 
-        On refresh, all sub-resources are marked as stale, i.e.
-        greedy-refresh not done for them unless forced by ``force``
-        argument.
+        :returns: :class:`sushy.resources.settings.SettingsUpdate` object
+            containing status and any messages
         """
-        if self._pending_settings_resource is not None:
-            self._pending_settings_resource.invalidate(force)
+        return self._settings.get_status(self._registries)
