@@ -19,6 +19,7 @@ import mock
 
 from sushy.resources import constants as res_cons
 from sushy.resources.registry import message_registry
+from sushy.resources import settings
 from sushy.tests.unit import base
 
 
@@ -65,3 +66,44 @@ class MessageRegistryTestCase(base.TestCase):
         self.assertRaisesRegex(KeyError,
                                'unknown_type',
                                self.registry._parse_attributes)
+
+    def test_parse_message(self):
+        conn = mock.Mock()
+        with open('sushy/tests/unit/json_samples/message_registry.json') as f:
+            conn.get.return_value.json.return_value = json.load(f)
+        registry = message_registry.MessageRegistry(
+            conn, '/redfish/v1/Registries/Test',
+            redfish_version='1.0.2')
+        registries = {'Test.1.0.0': registry}
+        message_field = settings.MessageListField('Foo')
+        message_field.message_id = 'Test.1.0.0.TooBig'
+        message_field.message_args = ['arg1', 10]
+        message_field.severity = None
+        message_field.resolution = None
+
+        parsed_msg = message_registry.parse_message(registries, message_field)
+
+        self.assertEqual('Try again', parsed_msg.resolution)
+        self.assertEqual(res_cons.SEVERITY_WARNING, parsed_msg.severity)
+        self.assertEqual('Property\'s arg1 value cannot be greater than 10.',
+                         parsed_msg.message)
+
+    def test_parse_message_with_severity_resolution_no_args(self):
+        conn = mock.Mock()
+        with open('sushy/tests/unit/json_samples/message_registry.json') as f:
+            conn.get.return_value.json.return_value = json.load(f)
+        registry = message_registry.MessageRegistry(
+            conn, '/redfish/v1/Registries/Test',
+            redfish_version='1.0.2')
+        registries = {'Test.1.0.0': registry}
+        message_field = settings.MessageListField('Foo')
+        message_field.message_id = 'Test.1.0.0.Success'
+        message_field.severity = res_cons.SEVERITY_OK
+        message_field.resolution = 'Do nothing'
+
+        parsed_msg = message_registry.parse_message(registries, message_field)
+
+        self.assertEqual('Do nothing', parsed_msg.resolution)
+        self.assertEqual(res_cons.SEVERITY_OK, parsed_msg.severity)
+        self.assertEqual('Everything done successfully.',
+                         parsed_msg.message)
