@@ -14,9 +14,10 @@
 #    under the License.
 
 import json
-
 import mock
 
+from dateutil import parser
+
 import sushy
 from sushy import exceptions
 from sushy.resources.chassis import chassis
@@ -52,14 +53,15 @@ class SystemTestCase(base.TestCase):
         self.assertEqual('Web Front End node', self.sys_inst.description)
         self.assertEqual('web483', self.sys_inst.hostname)
         self.assertEqual('437XR1138R2', self.sys_inst.identity)
-        self.assertEqual(sushy.SYSTEM_INDICATOR_LED_OFF,
+        self.assertEqual(sushy.INDICATOR_LED_OFF,
                          self.sys_inst.indicator_led)
         self.assertEqual('Contoso', self.sys_inst.manufacturer)
         self.assertEqual('WebFrontEnd483', self.sys_inst.name)
         self.assertEqual('224071-J23', self.sys_inst.part_number)
         self.assertEqual('437XR1138R2', self.sys_inst.serial_number)
         self.assertEqual('8675309', self.sys_inst.sku)
-        self.assertEqual('Physical', self.sys_inst.system_type)
+        self.assertEqual(sushy.SYSTEM_TYPE_PHYSICAL,
+                         self.sys_inst.system_type)
         self.assertEqual('38947555-7742-3448-3784-823347823834',
                          self.sys_inst.uuid)
         self.assertEqual(res_cons.STATE_ENABLED, self.sys_inst.status.state)
@@ -70,6 +72,12 @@ class SystemTestCase(base.TestCase):
                          self.sys_inst.power_state)
         self.assertEqual(96, self.sys_inst.memory_summary.size_gib)
         self.assertEqual("OK", self.sys_inst.memory_summary.health)
+        self.assertIsNotNone(self.sys_inst.maintenance_window)
+        self.assertEqual(1, self.sys_inst.maintenance_window
+                         .maintenance_window_duration_in_seconds)
+        self.assertEqual(parser.parse('2016-03-07T14:44:30-05:05'),
+                         self.sys_inst.maintenance_window
+                         .maintenance_window_start_time)
         for oem_vendor in self.sys_inst.oem_vendors:
             self.assertIn(oem_vendor, ('Contoso', 'Chipwise'))
 
@@ -98,6 +106,14 @@ class SystemTestCase(base.TestCase):
         self.sys_inst._parse_attributes()
         self.assertIsNone(self.sys_inst.memory_summary.size_gib)
 
+    def test__parse_attributes_bad_maintenance_window_time(self):
+        self.sys_inst.json['@Redfish.MaintenanceWindow'][
+            'MaintenanceWindowStartTime'] = 'bad date'
+        self.assertRaisesRegex(
+            exceptions.MalformedAttributeError,
+            '@Redfish.MaintenanceWindow/MaintenanceWindowStartTime',
+            self.sys_inst._parse_attributes)
+
     def test_get__reset_action_element(self):
         value = self.sys_inst._get_reset_action_element()
         self.assertEqual("/redfish/v1/Systems/437XR1138R2/Actions/"
@@ -149,6 +165,17 @@ class SystemTestCase(base.TestCase):
         self.assertIsInstance(values, set)
         self.assertEqual(1, mock_log.call_count)
 
+    def test_reset_action_operation_apply_time_support(self):
+        support = self.sys_inst._actions.reset.operation_apply_time_support
+        self.assertIsNotNone(support)
+        self.assertEqual(['Immediate', 'AtMaintenanceWindowStart'],
+                         support.supported_values)
+        self.assertEqual(parser.parse('2017-05-03T23:12:37-05:00'),
+                         support.maintenance_window_start_time)
+        self.assertEqual(600, support.maintenance_window_duration_in_seconds)
+        self.assertEqual('/redfish/v1/Systems/437XR1138R2',
+                         support._maintenance_window_resource.resource_uri)
+
     def test_reset_system(self):
         self.sys_inst.reset_system(sushy.RESET_FORCE_OFF)
         self.sys_inst._conn.post.assert_called_once_with(
@@ -232,6 +259,21 @@ class SystemTestCase(base.TestCase):
                 sushy.BOOT_SOURCE_TARGET_HDD,
                 enabled='invalid-enabled')
 
+    def test_set_indicator_led(self):
+        with mock.patch.object(
+                self.sys_inst, 'invalidate', autospec=True) as invalidate_mock:
+            self.sys_inst.set_indicator_led(sushy.INDICATOR_LED_BLINKING)
+            self.sys_inst._conn.patch.assert_called_once_with(
+                '/redfish/v1/Systems/437XR1138R2',
+                data={'IndicatorLED': 'Blinking'})
+
+            invalidate_mock.assert_called_once_with()
+
+    def test_set_indicator_led_invalid_state(self):
+        self.assertRaises(exceptions.InvalidParameterValueError,
+                          self.sys_inst.set_indicator_led,
+                          'spooky-glowing')
+
     def test__get_processor_collection_path_missing_processors_attr(self):
         self.sys_inst._json.pop('Processors')
         self.assertRaisesRegex(
